@@ -28,6 +28,20 @@ exec_(OBJECTS_CODE, objects.__dict__, objects.__dict__)
 
 class TestAttributeAccess(unittest.TestCase):
 
+    def test_init_not_called(self):
+        a = wrapt.ObjectProxy.__new__(wrapt.ObjectProxy)
+        b = wrapt.ObjectProxy.__new__(wrapt.ObjectProxy)
+
+        try:
+            a.__wrapped__
+        except ValueError:
+            pass
+
+        try:
+            a + b
+        except ValueError:
+            pass
+
     def test_attributes(self):
         def function1(*args, **kwargs):
             return args, kwargs
@@ -153,7 +167,7 @@ class TestNamingObjectProxy(unittest.TestCase):
             self.assertEqual(wrapper.__qualname__, __qualname__)
 
     def test_class_module_name(self):
-       # Test preservation of class __module__ attribute.
+        # Test preservation of class __module__ attribute.
 
         target = objects.Target
         wrapper = wrapt.ObjectProxy(target)
@@ -169,7 +183,7 @@ class TestNamingObjectProxy(unittest.TestCase):
         self.assertEqual(wrapper.__doc__, target.__doc__)
 
     def test_instance_module_name(self):
-       # Test preservation of instance __module__ attribute.
+        # Test preservation of instance __module__ attribute.
 
         target = objects.Target()
         wrapper = wrapt.ObjectProxy(target)
@@ -206,7 +220,7 @@ class TestNamingObjectProxy(unittest.TestCase):
             self.assertEqual(wrapper.__qualname__, __qualname__)
 
     def test_function_module_name(self):
-       # Test preservation of function __module__ attribute.
+        # Test preservation of function __module__ attribute.
 
         target = objects.target
         wrapper = wrapt.ObjectProxy(target)
@@ -334,7 +348,7 @@ class TestCallingObject(unittest.TestCase):
 
     def test_function_kwargs(self):
         _args = ()
-        _kwargs = { "one": 1, "two": 2 }
+        _kwargs = {"one": 1, "two": 2}
 
         def function(*args, **kwargs):
             return args, kwargs
@@ -347,7 +361,7 @@ class TestCallingObject(unittest.TestCase):
 
     def test_function_args_plus_kwargs(self):
         _args = (1, 2)
-        _kwargs = { "one": 1, "two": 2 }
+        _kwargs = {"one": 1, "two": 2}
 
         def function(*args, **kwargs):
             return args, kwargs
@@ -388,7 +402,7 @@ class TestCallingObject(unittest.TestCase):
 
     def test_instancemethod_kwargs(self):
         _args = ()
-        _kwargs = { "one": 1, "two": 2 }
+        _kwargs = {"one": 1, "two": 2}
 
         class Class(object):
             def function(self, *args, **kwargs):
@@ -402,7 +416,7 @@ class TestCallingObject(unittest.TestCase):
 
     def test_instancemethod_args_plus_kwargs(self):
         _args = (1, 2)
-        _kwargs = { "one": 1, "two": 2 }
+        _kwargs = {"one": 1, "two": 2}
 
         class Class(object):
             def function(self, *args, **kwargs):
@@ -444,7 +458,7 @@ class TestCallingObject(unittest.TestCase):
 
     def test_instancemethod_via_class_kwargs(self):
         _args = ()
-        _kwargs = { "one": 1, "two": 2 }
+        _kwargs = {"one": 1, "two": 2}
 
         class Class(object):
             def function(self, *args, **kwargs):
@@ -458,7 +472,7 @@ class TestCallingObject(unittest.TestCase):
 
     def test_instancemethod_via_class_args_plus_kwargs(self):
         _args = (1, 2)
-        _kwargs = { "one": 1, "two": 2 }
+        _kwargs = {"one": 1, "two": 2}
 
         class Class(object):
             def function(self, *args, **kwargs):
@@ -502,7 +516,7 @@ class TestCallingObject(unittest.TestCase):
 
     def test_classmethod_kwargs(self):
         _args = ()
-        _kwargs = { "one": 1, "two": 2 }
+        _kwargs = {"one": 1, "two": 2}
 
         class Class(object):
             @classmethod
@@ -517,7 +531,7 @@ class TestCallingObject(unittest.TestCase):
 
     def test_classmethod_args_plus_kwargs(self):
         _args = (1, 2)
-        _kwargs = { "one": 1, "two": 2 }
+        _kwargs = {"one": 1, "two": 2}
 
         class Class(object):
             @classmethod
@@ -562,7 +576,7 @@ class TestCallingObject(unittest.TestCase):
 
     def test_classmethod_via_class_kwargs(self):
         _args = ()
-        _kwargs = { "one": 1, "two": 2 }
+        _kwargs = {"one": 1, "two": 2}
 
         class Class(object):
             @classmethod
@@ -577,7 +591,7 @@ class TestCallingObject(unittest.TestCase):
 
     def test_classmethod_via_class_args_plus_kwargs(self):
         _args = (1, 2)
-        _kwargs = { "one": 1, "two": 2 }
+        _kwargs = {"one": 1, "two": 2}
 
         class Class(object):
             @classmethod
@@ -622,7 +636,7 @@ class TestCallingObject(unittest.TestCase):
 
     def test_staticmethod_kwargs(self):
         _args = ()
-        _kwargs = { "one": 1, "two": 2 }
+        _kwargs = {"one": 1, "two": 2}
 
         class Class(object):
             @staticmethod
@@ -637,7 +651,7 @@ class TestCallingObject(unittest.TestCase):
 
     def test_staticmethod_args_plus_kwargs(self):
         _args = (1, 2)
-        _kwargs = { "one": 1, "two": 2 }
+        _kwargs = {"one": 1, "two": 2}
 
         class Class(object):
             @staticmethod
@@ -682,7 +696,7 @@ class TestCallingObject(unittest.TestCase):
 
     def test_staticmethod_via_class_kwargs(self):
         _args = ()
-        _kwargs = { "one": 1, "two": 2 }
+        _kwargs = {"one": 1, "two": 2}
 
         class Class(object):
             @staticmethod
@@ -697,7 +711,7 @@ class TestCallingObject(unittest.TestCase):
 
     def test_staticmethod_via_class_args_plus_kwargs(self):
         _args = (1, 2)
-        _kwargs = { "one": 1, "two": 2 }
+        _kwargs = {"one": 1, "two": 2}
 
         class Class(object):
             @staticmethod
@@ -853,21 +867,21 @@ class TestAsNumberObjectProxy(unittest.TestCase):
         self.assertEqual(2/three, 2/3)
         self.assertEqual(two/3, 2/3)
 
-    def test_mod(self):
+    def test_floordiv(self):
         two = wrapt.ObjectProxy(2)
-        three = wrapt.ObjectProxy(3)
+        four = wrapt.ObjectProxy(4)
 
-        self.assertEqual(three//two, 3//2)
-        self.assertEqual(3//two, 3//2)
-        self.assertEqual(three//2, 3//2)
+        self.assertEqual(four//two, 4//2)
+        self.assertEqual(4//two, 4//2)
+        self.assertEqual(four//2, 4//2)
 
     def test_mod(self):
         two = wrapt.ObjectProxy(2)
-        three = wrapt.ObjectProxy(3)
+        four = wrapt.ObjectProxy(4)
 
-        self.assertEqual(three%two, 3%2)
-        self.assertEqual(3%two, 3%2)
-        self.assertEqual(three%2, 3%2)
+        self.assertEqual(four % two, 4 % 2)
+        self.assertEqual(4 % two, 4 % 2)
+        self.assertEqual(four % 2, 4 % 2)
 
     def test_divmod(self):
         two = wrapt.ObjectProxy(2)
@@ -901,41 +915,41 @@ class TestAsNumberObjectProxy(unittest.TestCase):
         two = wrapt.ObjectProxy(2)
         three = wrapt.ObjectProxy(3)
 
-        self.assertEqual(three<<two, 3<<2)
-        self.assertEqual(3<<two, 3<<2)
-        self.assertEqual(three<<2, 3<<2)
+        self.assertEqual(three << two, 3 << 2)
+        self.assertEqual(3 << two, 3 << 2)
+        self.assertEqual(three << 2, 3 << 2)
 
     def test_rshift(self):
         two = wrapt.ObjectProxy(2)
         three = wrapt.ObjectProxy(3)
 
-        self.assertEqual(three>>two, 3>>2)
-        self.assertEqual(3>>two, 3>>2)
-        self.assertEqual(three>>2, 3>>2)
+        self.assertEqual(three >> two, 3 >> 2)
+        self.assertEqual(3 >> two, 3 >> 2)
+        self.assertEqual(three >> 2, 3 >> 2)
 
     def test_and(self):
         two = wrapt.ObjectProxy(2)
         three = wrapt.ObjectProxy(3)
 
-        self.assertEqual(three&two, 3&2)
-        self.assertEqual(3&two, 3&2)
-        self.assertEqual(three&2, 3&2)
+        self.assertEqual(three & two, 3 & 2)
+        self.assertEqual(3 & two, 3 & 2)
+        self.assertEqual(three & 2, 3 & 2)
 
     def test_xor(self):
         two = wrapt.ObjectProxy(2)
         three = wrapt.ObjectProxy(3)
 
-        self.assertEqual(three^two, 3^2)
-        self.assertEqual(3^two, 3^2)
-        self.assertEqual(three^2, 3^2)
+        self.assertEqual(three ^ two, 3 ^ 2)
+        self.assertEqual(3 ^ two, 3 ^ 2)
+        self.assertEqual(three ^ 2, 3 ^ 2)
 
     def test_or(self):
         two = wrapt.ObjectProxy(2)
         three = wrapt.ObjectProxy(3)
 
-        self.assertEqual(three|two, 3|2)
-        self.assertEqual(3|two, 3|2)
-        self.assertEqual(three|2, 3|2)
+        self.assertEqual(three | two, 3 | 2)
+        self.assertEqual(3 | two, 3 | 2)
+        self.assertEqual(three | 2, 3 | 2)
 
     def test_iadd(self):
         value = wrapt.ObjectProxy(1)
@@ -1015,12 +1029,12 @@ class TestAsNumberObjectProxy(unittest.TestCase):
         two = wrapt.ObjectProxy(2)
 
         value %= 2
-        self.assertEqual(value, 10%2)
+        self.assertEqual(value, 10 % 2)
 
         self.assertEqual(type(value), wrapt.ObjectProxy)
 
         value %= two
-        self.assertEqual(value, 10%2%2)
+        self.assertEqual(value, 10 % 2 % 2)
 
         self.assertEqual(type(value), wrapt.ObjectProxy)
 
@@ -1043,12 +1057,12 @@ class TestAsNumberObjectProxy(unittest.TestCase):
         two = wrapt.ObjectProxy(2)
 
         value <<= 2
-        self.assertEqual(value, 256<<2)
+        self.assertEqual(value, 256 << 2)
 
         self.assertEqual(type(value), wrapt.ObjectProxy)
 
         value <<= two
-        self.assertEqual(value, 256<<2<<2)
+        self.assertEqual(value, 256 << 2 << 2)
 
         self.assertEqual(type(value), wrapt.ObjectProxy)
 
@@ -1057,12 +1071,12 @@ class TestAsNumberObjectProxy(unittest.TestCase):
         two = wrapt.ObjectProxy(2)
 
         value >>= 2
-        self.assertEqual(value, 2>>2)
+        self.assertEqual(value, 2 >> 2)
 
         self.assertEqual(type(value), wrapt.ObjectProxy)
 
         value >>= two
-        self.assertEqual(value, 2>>2>>2)
+        self.assertEqual(value, 2 >> 2 >> 2)
 
         self.assertEqual(type(value), wrapt.ObjectProxy)
 
@@ -1071,12 +1085,12 @@ class TestAsNumberObjectProxy(unittest.TestCase):
         two = wrapt.ObjectProxy(2)
 
         value &= 2
-        self.assertEqual(value, 1&2)
+        self.assertEqual(value, 1 & 2)
 
         self.assertEqual(type(value), wrapt.ObjectProxy)
 
         value &= two
-        self.assertEqual(value, 1&2&2)
+        self.assertEqual(value, 1 & 2 & 2)
 
         self.assertEqual(type(value), wrapt.ObjectProxy)
 
@@ -1085,12 +1099,12 @@ class TestAsNumberObjectProxy(unittest.TestCase):
         two = wrapt.ObjectProxy(2)
 
         value ^= 2
-        self.assertEqual(value, 1^2)
+        self.assertEqual(value, 1 ^ 2)
 
         self.assertEqual(type(value), wrapt.ObjectProxy)
 
         value ^= two
-        self.assertEqual(value, 1^2^2)
+        self.assertEqual(value, 1 ^ 2 ^ 2)
 
         self.assertEqual(type(value), wrapt.ObjectProxy)
 
@@ -1099,12 +1113,12 @@ class TestAsNumberObjectProxy(unittest.TestCase):
         two = wrapt.ObjectProxy(2)
 
         value |= 2
-        self.assertEqual(value, 1|2)
+        self.assertEqual(value, 1 | 2)
 
         self.assertEqual(type(value), wrapt.ObjectProxy)
 
         value |= two
-        self.assertEqual(value, 1|2|2)
+        self.assertEqual(value, 1 | 2 | 2)
 
         self.assertEqual(type(value), wrapt.ObjectProxy)
 
@@ -1249,9 +1263,9 @@ class TestObjectRepresentationObjectProxy(unittest.TestCase):
 
         self.assertEqual(str(value), str([10]))
 
-        value = wrapt.ObjectProxy({10:10})
+        value = wrapt.ObjectProxy({10: 10})
 
-        self.assertEqual(str(value), str({10:10}))
+        self.assertEqual(str(value), str({10: 10}))
 
     def test_repr(self):
         number = 10
@@ -1290,6 +1304,21 @@ class TestDerivedClassCreation(unittest.TestCase):
 
         obj = DerivedObjectProxy(function)
 
+    def test_derived_missing_init(self):
+
+        class DerivedObjectProxy(wrapt.ObjectProxy):
+
+            def __init__(self, wrapped):
+                self.__wrapped__ = wrapped
+
+        def function():
+            pass
+
+        obj = DerivedObjectProxy(function)
+
+        self.assertEqual(function, obj)
+        self.assertEqual(function, obj.__wrapped__)
+
 class DerivedClassAttributes(unittest.TestCase):
 
     def test_setup_class_attributes(self):
